@@ -5,10 +5,12 @@ DIC <- function(object, ...)
 
 DIC.ramps <- function(object, ...)
 {
-   ## Posterior parameter means
+  ## Posterior parameter means
    w <- rep(1 / nrow(object$params), nrow(object$params))
-   params <- as.vector(crossprod(w, object$params))
-   loglik <- as.numeric(crossprod(w, object$loglik))
+   params <- as.vector(crossprod(object$params, w))
+   loglik <- as.numeric(crossprod(object$loglik, w))
+   
+   BETA <- params2beta(params, object$control)
 
    switch(object$control$mpdfun,
       mpdbeta = {
@@ -17,6 +19,11 @@ DIC.ramps <- function(object, ...)
                         object$retype, object$weights, object$control)
       },
       mpdbetaz = {
+         if(!all(object$control$z$monitor))
+           stop("All z must be monitored to compute DIC")
+         
+         BETA <- c(BETA, as.vector(object$kmat %*% crossprod(object$z, w)))
+
          sites <- unique.sites(object$kmat)
          xk1mat <- cBind(object$xmat, sites$map)
          k2mat <- sites$coords
@@ -27,7 +34,8 @@ DIC.ramps <- function(object, ...)
       }
    )
    loglik.mu <-  -0.5 * length(object$y) * log(2.0 * pi) - val$logsqrtdet -
-                    val$quadform[1] / 2.0
+                    (crossprod(val$uXtSiginvX %*% (val$betahat - BETA))[1]
+                     + val$quadform[1]) / 2.0
 
    ## Deviance information criterion
    pD <- -2.0 * (loglik - loglik.mu)
