@@ -2,6 +2,10 @@
 ## window.ramps/window.predict.ramps - Time windows for ramps MCMC output
 ################################################################################
 
+.onLoad <- function(lib, pkg) {
+   setAs("matrix", "data.frame", function(from) as.data.frame(from))
+}
+
 window.ramps <- function(x, iter, ...)
 {
    idx <- match(iter, as.numeric(rownames(x$params)))
@@ -268,6 +272,7 @@ inbounds <- function(x, bounds)
    val
 }
 
+
 unique.sites <- function(x)
 {
    type <- class(x)
